#' A matrix with categories
#' @usage data(raster_x)
#' @format A matrix
"raster_x"

#' A matrix with categories
#' @usage data(raster_y)
#' @format A matrix
"raster_y"

#' A matrix with weights
#' @usage data(raster_w)
#' @format A matrix
"raster_w"

#' A matrix with categories and missing values
#' @usage data(raster_x_na)
#' @format A matrix
"raster_x_na"

#' A matrix with weights and missing values
#' @usage data(raster_w_na)
#' @format A matrix
"raster_w_na"
